exceptiontools.MeasureError
===========================

.. abjad-lineage:: abjad.tools.exceptiontools.MeasureError.MeasureError

.. autoclass:: abjad.tools.exceptiontools.MeasureError.MeasureError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__unicode__
   :noindex:
